
# gketap

A CLI tool to tap into GKE clusters via SSH tunnels through a bastion host.

## Install

```bash
pip install gketap
```

## Usage

```bash
gketap discover
gketap start <cluster>
gketap stop
gketap status
```
